.. include:: ../CHANGES.rst


Older Releases
==============

For full information on older versions, see :doc:`older_releases`.

.. toctree::
   :caption: Older change logs, without context.
   :maxdepth: 2

   changelog_1_5
   changelog_1_4
   changelog_1_3
   changelog_1_2
   changelog_1_1
   changelog_1_0
   changelog_pre
